@@ -5,7 +5,7 @@ from urllib.parse import urlparse
 import json
 import tempfile
 
-from jinja2 import Template
+from spark_etl.template import GenTemplate
 
 import oci
 from oci_core import get_os_client, get_df_client, os_upload, os_upload_json
@@ -13,6 +13,7 @@ from oci_core import get_os_client, get_df_client, os_upload, os_upload_json
 from spark_etl.deployers import AbstractDeployer
 from spark_etl import Build, SparkETLDeploymentFailure
 from .tools import check_response, remote_execute
+from spark_etl.misc_tools import read_textfile
 
 def _save_json_temp(payload):
     # save a dict to temporary json file, and return filename
@@ -31,25 +32,23 @@ def get_job_loader(oci_config):
     if oci_config is not None:
         oci_cfg = dict(oci_config)
         key_file = oci_cfg.pop("key_file")
-        with open(key_file, "rt") as key_f:
-            oci_key = key_f.read()
+        oci_key = read_textfile(key_file)
 
-    with open(job_loader_filename, "rt") as f:
-        load_content = f.read()
-        template = Template(load_content)
-        if oci_config is None:
-            c = template.render(
-                use_instance_principle = True,
-            )
-        else:
-            c = template.render(
-                use_instance_principle = False,
-                oci_config_str = json.dumps(oci_cfg, indent=4),
-                oci_key = oci_key
-            )
-        with tempfile.NamedTemporaryFile(mode='w+t', delete=False) as f:
-            f.write(c)
-            return f.name
+    template = GenTemplate()
+    if oci_config is None:
+        c = template.render(job_loader_filename,
+            use_instance_principle = True,
+        )
+    else:
+        c = template.render(job_loader_filename,
+            use_instance_principle = False,
+            oci_config_str = json.dumps(oci_cfg, indent=4),
+            oci_key = oci_key
+        )
+
+    with tempfile.NamedTemporaryFile(mode='w+t', delete=False) as f:
+        f.write(c)
+        return f.name
 
 
 class DataflowDeployer(AbstractDeployer):
